@@ -27,7 +27,10 @@ fn main() {
                                       "$HOME/.config/xplr/init.lua")
     -C, --extra-config <PATH>...    Specifies extra config files to load
         --on-load <MESSAGE>...      Sends messages when xplr loads
-        --force-focus               Focuses on the given <PATH>, even if directory"###;
+        --force-focus               Focuses on the given <PATH>, even if it is
+                                      a directory
+        --print-pwd-as-result       Prints the last working directory when
+                                      quitting with `PrintResultAndQuit`"###;
 
         let args = r###"
     <PATH>            Path to focus on, or enter if directory, (default is `.`)
